summaryrefslogtreecommitdiff
path: root/src/main/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/main.cpp')
-rw-r--r--src/main/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main/main.cpp b/src/main/main.cpp
index a4e70be89..6a7baebb3 100644
--- a/src/main/main.cpp
+++ b/src/main/main.cpp
@@ -41,13 +41,13 @@ using namespace cvc5::language;
* cvc5's main() routine is just an exception-safe wrapper around cvc5.
* Please don't construct anything here. Even if the constructor is
* inside the try { }, an exception during destruction can cause
* problems. That's why main() wraps runCvc4() in the first place.
* Put everything in runCvc4().
*/
int main(int argc, char* argv[]) {
Options opts;
try {
- return runCvc4(argc, argv, opts);
+ return runCvc5(argc, argv, opts);
} catch(OptionException& e) {
#ifdef CVC5_COMPETITION_MODE
*opts.getOut() << "unknown" << endl;
@@ -41,13 +41,13 @@ using namespace cvc5::language;
* Please don't construct anything here. Even if the constructor is
* inside the try { }, an exception during destruction can cause
- * problems. That's why main() wraps runCvc4() in the first place.
- * Put everything in runCvc4().
+ * problems. That's why main() wraps runCvc5() in the first place.
+ * Put everything in runCvc5().
*/
int main(int argc, char* argv[]) {
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback